#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const commander = require("commander");
const configureHelpOptions_1 = require("../utils/configureHelpOptions");
const isWizCliCommand_1 = require("../utils/isWizCliCommand");
const checkForUpdate_1 = require("./utils/checkForUpdate");
const checkNodeVersion_1 = require("./utils/checkNodeVersion");
(0, checkNodeVersion_1.default)();
const logger_1 = require("./utils/logger");
commander
    .version(require('../../package').version)
    .usage('<command> [options]')
    .command('init [type] [project]', 'Initialize a project')
    .command('chapter [chapter]', 'Generate chapter')
    .command('slide [slideId...]', 'Generate slide')
    .command('subslide [subId..]', 'Generate subslide')
    .command('install [components...]', 'Install components')
    .alias('i')
    .command('uninstall <components...>', 'Uninstall components')
    .alias('rm')
    .command('publish', 'Publish component')
    .command('unpublish <component>', 'Unpublish component')
    .command('login', 'Log in Ewizard CLI')
    .command('logout', 'Log out Ewizard CLI')
    .command('docs', 'View eWizard CLI documentation')
    .command('dev', 'Run dev build')
    .command('config', 'Configure eWizard CLI')
    .command('archive', 'Run dev build and archive content folder')
    .command('thumbs', 'Generate thumbnails')
    .command('khalifa', 'Makes you smile', { hidden: true })
    .command('screen <command> [options]', 'Generate screenshots')
    .command('create <command> [options]', 'Create an email on master template')
    .command('component <command> [options]', 'Standalone component commands')
    .command('clone', 'Clone content with id')
    .command('pull', 'Applies the upstream changes to your local project')
    .command('push', 'Push your local changes to the upstream eWizard project')
    .command('update', 'Update the dependencies and component versions in the currently open project')
    .alias('up')
    .configureHelp({
    optionDescription: configureHelpOptions_1.capitalizeOptionDescription,
    subcommandDescription: configureHelpOptions_1.capitalizeSubcommandDescription,
});
try {
    (0, checkForUpdate_1.default)();
    (0, isWizCliCommand_1.checkIsWizCliCommand)(commander);
}
catch (e) {
    (0, logger_1.handleError)(e);
}
finally {
    (0, logger_1.closeLogger)();
}
//# sourceMappingURL=wiz.js.map